# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-05-18 17:34
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(help_text=b'Short descriptive name for this category.', max_length=200)),
                ('subtitle', models.CharField(blank=True, default=b'', help_text=b'Some titles may be the same and cause confusion in admin UI. A subtitle makes a distinction.', max_length=200, null=True)),
                ('slug', models.SlugField(help_text=b'Short descriptive unique name for use in urls.', max_length=255, unique=True)),
                ('parent', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='category.Category')),
                ('sites', models.ManyToManyField(blank=True, help_text=b'Limits category scope to selected sites.', null=True, to='sites.Site')),
            ],
            options={
                'ordering': ('title',),
                'verbose_name': 'category',
                'verbose_name_plural': 'categories',
            },
        ),
        migrations.CreateModel(
            name='Tag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(help_text=b'Short descriptive name for this tag.', max_length=200)),
                ('slug', models.SlugField(help_text=b'Short descriptive unique name for use in urls.', max_length=255, unique=True)),
                ('categories', models.ManyToManyField(blank=True, help_text=b'Categories to which this tag belongs.', null=True, to='category.Category')),
            ],
            options={
                'ordering': ('title',),
                'verbose_name': 'tag',
                'verbose_name_plural': 'tags',
            },
        ),
    ]



USE_TZ = True

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': 'django',
        'USER': 'postgres',
        'PASSWORD': '',
        'HOST': '',
        'PORT': '',
    }
}

INSTALLED_APPS = (
    'category',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sites',
    'south',
)

SITE_ID = 1

SECRET_KEY = 'SECRET_KEY'

SOUTH_TESTS_MIGRATE = False



from django.utils.translation import ugettext_lazy as _
from django.template import RequestContext
from django.shortcuts import render_to_response

import object_tools

from category.models import Category


class Tree(object_tools.ObjectTool):
    name = "tree"
    label = _("Tree")

    def view(self, request, extra_context=None):
        return render_to_response(
            "admin/category/tree.html",
            {"categories" : Category.objects.filter(
                parent=None).order_by("title")
            },
            RequestContext(request, {}),
        )


object_tools.tools.register(Tree, Category)



import unittest

from category import admin, models


class TestCase(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        cls.cat1 = models.Category.objects.create(title="Cat 1", slug="cat1")
        cls.cat2 = models.Category.objects.create(title="Cat 2", slug="cat2")

    def test_circular_reference(self):
        """Confirm a category cannot have itself as an ancestor"""
        self.cat1.parent = self.cat2
        self.cat1.save()
        self.cat2.parent = self.cat1
        self.assertRaises(RuntimeError, self.cat2.save)



from setuptools import setup, find_packages

setup(
    name="django-category",
    version="1.11.0",
    description="Django categorize content app.",
    long_description = open("README.rst", "r").read() + open("AUTHORS.rst", "r").read() + open("CHANGELOG.rst", "r").read(),
    author="Praekelt Consulting",
    author_email="dev@praekelt.com",
    license="BSD",
    url="http://github.com/praekelt/django-category",
    packages=find_packages(),
    include_package_data=True,
    install_requires = [
        "django",
        "django-object-tools>=1.9",
        "South>=1.0.2"
    ],
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: BSD License",
        "Development Status :: 5 - Production/Stable",
        "Operating System :: OS Independent",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
    zip_safe=False,
)

